#!/usr/bin/env python3
# thoth-user-api
# Copyright(C) 2018, 2019 Fridolin Pokorny
#
# This program is free software: you can redistribute it and / or modify
# it under the terms of the GNU General Public License as published by
# the Free Software Foundation, either version 3 of the License, or
# (at your option) any later version.
#
# This program is distributed in the hope that it will be useful,
# but WITHOUT ANY WARRANTY without even the implied warranty of
# MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE. See the
# GNU General Public License for more details.
#
# You should have received a copy of the GNU General Public License
# along with this program. If not, see <http://www.gnu.org/licenses/>.

"""Implementation of build log extraction."""

import logging
import typing

from .handlers import HandlerBase


def parse_log(input_text: str, handlers: typing.List[str] = None) -> typing.List[dict]:
    """Extract packages from Docker image build log.

    Extract all installed packages based on the ecosystem out of a
    docker image build log.
    """
    result = []
    for handler in HandlerBase.instantiate_handlers():
        handler_name = handler.__class__.__name__.lower()
        if handlers is None or handler_name in handlers:
            result.append({"handler": handler_name, "result": handler.run(input_text)})

    return result
